==> websvn-2.3.3-7-any.pkg.tar.xz: srv/http/websvn/languages/uzbek.php <==
<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// uzbek.php
//
// Uzbek language strings (UTF-8 encoding)
// by Behzod Saidov <behzodsaidov@gmail.com>

$lang["LANGUAGETAG"] = "uz"; // Language tag (RFC 4646) for this translation.
$lang["LANGUAGENAMEENGLISH"] = "Uzbek";
$lang["LANGUAGENAMENATIVE"] = "Oëzbekcha";
$lang["LANGUAGENAMEHTML"] = "O&euml;zbekcha";

$lang["LOG"] = "Log";
$lang["DIFF"] = "Farq";

$lang["NOREP"] = "Ombor koʻrsatilmagan";
$lang["NOPATH"] = "Yoʻl topilmadi";
$lang["NOACCESS"] = "Bu katalogni oʻqish uchun sizga ruxsat berilmagan";
$lang["RESTRICTED"] = "Cheklangan ruxsat";
$lang["SUPPLYREP"] = "Iltimos, repositoriylargacha boʻlgan yoʻlni include/config.php faylida koʻrsating, bunda \$config->parentPath yoki \$config->addRepository<p> dan foydalanishingiz mumkin. Qoʻshimcha maʼlumotlar oʻrnatish boʻyicha qoʻllanmada keltirilgan";

$lang["DIFFREVS"] = "Tahrirlar orasidagi farq";
$lang["AND"] = "va";
$lang["REV"] = "Tahrir";
$lang["LINE"] = "Satr";
$lang["LINENO"] = "Satr raqami";
$lang["SHOWENTIREFILE"] = "faylni toʻliq koʻrsatish";
$lang["SHOWCOMPACT"] = "faqat farqli qismlarini koʻrsatish";
// $lang["IGNOREWHITESPACE"] = "Ignore whitespace";
// $lang["REGARDWHITESPACE"] = "Regard whitespace";

// $lang["LISTING"] = "Directory listing";
// $lang["FILEDETAIL"] = "Details";
// $lang["VIEWAS"] = "View as";
$lang["DIFFPREV"] = "oldingisi bilan taqqoslash";
$lang["BLAME"] = "mualliflik";
$lang["BLAMEFOR"] = "Tahrir muallifi haqida maʼlumot";

$lang["REVINFO"] = "Tahrir haqida maʼlimot";
$lang["GOYOUNGEST"] = "eng yangi tahrirga oʻtish";
$lang["LASTMOD"] = "Oxirgi oʻzgarish";
$lang["LOGMSG"] = "Log yozuvi";
$lang["CHANGES"] = "Oʻzgarishlar";
$lang["SHOWCHANGED"] = "oʻzgargan fayllarni koʻrsatish";
$lang["HIDECHANGED"] = "oʻzgargan fayllarni yashirish";
$lang["NEWFILES"] = "Yangi fayllar";
$lang["CHANGEDFILES"] = "Oʻzgargan fayllar";
$lang["DELETEDFILES"] = "Oʻchirilgan fayllar";
$lang["VIEWLOG"] = "loglarni ochish";
$lang["PATH"] = "Yoʻl";
$lang["AUTHOR"] = "Muallif";
$lang["AGE"] = "Yoshi";
$lang["CURDIR"] = "Joriy katalog";
$lang["TARBALL"] = "Arxiv";
// $lang["DOWNLOAD"] = "Download";

$lang["PREV"] = "old.";
$lang["NEXT"] = "key.";
$lang["SHOWALL"] = "hammasini koʻrsatish";

$lang["BADCMD"] = "Buyruqni bajarishda xatolik roʻy berdi";
$lang["UNKNOWNREVISION"] = "Tahrir topilmadi";

$lang["POWERED"] = "<a href=\"http://www.websvn.info/\">WebSVN</a> dasturi ishlatilmoqda";
$lang["PROJECTS"] = "Subversion ombori ";
$lang["SERVER"] = "Subversion serveri ";

$lang["FILTER"] = "Filtr parametrlari";
$lang["STARTLOG"] = "Tahrirdan";
$lang["ENDLOG"] = "Tahrirgacha";
$lang["MAXLOG"] = "Maksimal tahrirlar";
$lang["SEARCHLOG"] = "qidirish";
$lang["CLEARLOG"] = "joriy filtrni tozalash";
$lang["MORERESULTS"] = "yana qidirish...";
$lang["NORESULTS"] = "Soʻrovingizga toʻgʻri keladigan yozuv topilmadi";
$lang["NOMORERESULTS"] = "Soʻrovingizga toʻgʻri keladigan yozuvlar boshqa topilmadi";
// $lang["NOPREVREV"] = "No previous revision";

$lang["RSSFEEDTITLE"] = "WebSVN RSS tarmasi";
$lang["FILESMODIFIED"] = "fayl(lar) oʻzgartirilgan";
$lang["RSSFEED"] = "RSS tasma";

$lang["DAYLETTER"] = "kun";
$lang["HOURLETTER"] = "soat";
$lang["MINUTELETTER"] = "daq.";
$lang["SECONDLETTER"] = "son.";

$lang["GO"] = "Oʻtish";

$lang["PATHCOMPARISON"] = "Yoʻllarni taqqoslash";
$lang["COMPAREPATHS"] = "yoʻllarni taqqoslash";
$lang["COMPAREREVS"] = "Tahrirlarni taqqoslash";
$lang["PROPCHANGES"] = "Xususiyatlardagi oʻzgarishlar:";
$lang["CONVFROM"] = "Bu taqqoslash yoʻlni aylantirish uchun kerak boʻladigan oʻzgarishlarni koʻrsatadi.";
$lang["TO"] = "TO";
$lang["REVCOMP"] = "teskari taqqoslash";
$lang["COMPPATH"] = "Yoʻlni taqqoslash:";
$lang["WITHPATH"] = "Yoʻl bilan:";
$lang["FILEDELETED"] = "Fayl oʻchirilgan";
$lang["FILEADDED"] = "Yangi fayl";

==> websvn-2.5-1-any.pkg.tar.xz: srv/http/websvn/languages/uzbek.php <==
<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// uzbek.php
//
// Uzbek language strings (UTF-8 encoding)
// by Behzod Saidov <behzodsaidov@gmail.com>

$lang["LANGUAGETAG"] = "uz"; // Language tag (RFC 4646) for this translation.
$lang["LANGUAGENAMEENGLISH"] = "Uzbek";
$lang["LANGUAGENAMENATIVE"] = "Oëzbekcha";
$lang["LANGUAGENAMEHTML"] = "O&euml;zbekcha";

$lang["LOG"] = "Log";
$lang["DIFF"] = "Farq";

$lang["NOREP"] = "Ombor koʻrsatilmagan";
$lang["NOPATH"] = "Yoʻl topilmadi";
$lang["NOACCESS"] = "Bu katalogni oʻqish uchun sizga ruxsat berilmagan";
$lang["RESTRICTED"] = "Cheklangan ruxsat";
$lang["SUPPLYREP"] = "Iltimos, repositoriylargacha boʻlgan yoʻlni include/config.php faylida koʻrsating, bunda \$config->parentPath yoki \$config->addRepository<p> dan foydalanishingiz mumkin. Qoʻshimcha maʼlumotlar oʻrnatish boʻyicha qoʻllanmada keltirilgan";

$lang["DIFFREVS"] = "Tahrirlar orasidagi farq";
$lang["AND"] = "va";
$lang["REV"] = "Tahrir";
$lang["LINE"] = "Satr";
$lang["LINENO"] = "Satr raqami";
$lang["SHOWENTIREFILE"] = "faylni toʻliq koʻrsatish";
$lang["SHOWCOMPACT"] = "faqat farqli qismlarini koʻrsatish";
// $lang["IGNOREWHITESPACE"] = "Ignore whitespace";
// $lang["REGARDWHITESPACE"] = "Regard whitespace";

// $lang["LISTING"] = "Directory listing";
// $lang["FILEDETAIL"] = "Details";
// $lang["VIEWAS"] = "View as";
$lang["DIFFPREV"] = "oldingisi bilan taqqoslash";
$lang["BLAME"] = "mualliflik";
$lang["BLAMEFOR"] = "Tahrir muallifi haqida maʼlumot";

$lang["REVINFO"] = "Tahrir haqida maʼlimot";
$lang["GOYOUNGEST"] = "eng yangi tahrirga oʻtish";
$lang["LASTMOD"] = "Oxirgi oʻzgarish";
$lang["LOGMSG"] = "Log yozuvi";
$lang["CHANGES"] = "Oʻzgarishlar";
$lang["SHOWCHANGED"] = "oʻzgargan fayllarni koʻrsatish";
$lang["HIDECHANGED"] = "oʻzgargan fayllarni yashirish";
$lang["NEWFILES"] = "Yangi fayllar";
$lang["CHANGEDFILES"] = "Oʻzgargan fayllar";
$lang["DELETEDFILES"] = "Oʻchirilgan fayllar";
$lang["VIEWLOG"] = "loglarni ochish";
$lang["PATH"] = "Yoʻl";
$lang["AUTHOR"] = "Muallif";
$lang["AGE"] = "Yoshi";
$lang["CURDIR"] = "Joriy katalog";
$lang["TARBALL"] = "Arxiv";
// $lang["DOWNLOAD"] = "Download";

$lang["PREV"] = "old.";
$lang["NEXT"] = "key.";
$lang["SHOWALL"] = "hammasini koʻrsatish";

$lang["BADCMD"] = "Buyruqni bajarishda xatolik roʻy berdi";
$lang["UNKNOWNREVISION"] = "Tahrir topilmadi";

$lang["POWERED"] = "<a href=\"https://websvnphp.github.io/\">WebSVN</a> dasturi ishlatilmoqda";
$lang["PROJECTS"] = "Subversion ombori ";
$lang["SERVER"] = "Subversion serveri ";

$lang["FILTER"] = "Filtr parametrlari";
$lang["STARTLOG"] = "Tahrirdan";
$lang["ENDLOG"] = "Tahrirgacha";
$lang["MAXLOG"] = "Maksimal tahrirlar";
$lang["SEARCHLOG"] = "qidirish";
$lang["CLEARLOG"] = "joriy filtrni tozalash";
$lang["MORERESULTS"] = "yana qidirish...";
$lang["NORESULTS"] = "Soʻrovingizga toʻgʻri keladigan yozuv topilmadi";
$lang["NOMORERESULTS"] = "Soʻrovingizga toʻgʻri keladigan yozuvlar boshqa topilmadi";
// $lang["NOPREVREV"] = "No previous revision";

$lang["RSSFEEDTITLE"] = "WebSVN RSS tarmasi";
$lang["FILESMODIFIED"] = "fayl(lar) oʻzgartirilgan";
$lang["RSSFEED"] = "RSS tasma";

$lang["DAYLETTER"] = "kun";
$lang["HOURLETTER"] = "soat";
$lang["MINUTELETTER"] = "daq.";
$lang["SECONDLETTER"] = "son.";

$lang["GO"] = "Oʻtish";

$lang["PATHCOMPARISON"] = "Yoʻllarni taqqoslash";
$lang["COMPAREPATHS"] = "yoʻllarni taqqoslash";
$lang["COMPAREREVS"] = "Tahrirlarni taqqoslash";
$lang["PROPCHANGES"] = "Xususiyatlardagi oʻzgarishlar:";
$lang["CONVFROM"] = "Bu taqqoslash yoʻlni aylantirish uchun kerak boʻladigan oʻzgarishlarni koʻrsatadi.";
$lang["TO"] = "TO";
$lang["REVCOMP"] = "teskari taqqoslash";
$lang["COMPPATH"] = "Yoʻlni taqqoslash:";
$lang["WITHPATH"] = "Yoʻl bilan:";
$lang["FILEDELETED"] = "Fayl oʻchirilgan";
$lang["FILEADDED"] = "Yangi fayl";
